@@ -65,7 +65,7 @@ require Exporter;
 *import = \&Exporter::import;
 require DynaLoader;
 
-$HTTP::Server::EV::VERSION = '0.68';
+$HTTP::Server::EV::VERSION = '0.69';
 DynaLoader::bootstrap HTTP::Server::EV $HTTP::Server::EV::VERSION;
 
 @HTTP::Server::EV::EXPORT = ();
@@ -222,9 +222,9 @@ Binds callback to port. Calls callback and passes L<HTTP::Server::EV::CGI> objec
 sub listen {
 	my ($self, $socket, $cb, $params) = @_;
 	
-	die "You can`t bind two listeners on one port!\n" if $listeners{$socket};
+	die "You can`t bind two listeners on one port!\n" if $HTTP::Server::EV::listeners{$socket};
 	
-	if(int $socket){
+	if(int($socket) eq $socket){
 		$params->{port} = $socket;
 	}else {
 		$params->{socket} = $socket;
@@ -232,8 +232,8 @@ sub listen {
 	$params->{cb} = $cb;
 	
 
-	$listeners{$socket} = HTTP::Server::EV::PortListener->new($params);
-}
+	$HTTP::Server::EV::listeners{$socket} = HTTP::Server::EV::PortListener->new($params);
+};
 
 
 
