@@ -11,7 +11,7 @@ no warnings;
 use HTTP::Server::EV::Buffer;
 use HTTP::Server::EV::BufTie;
 
-our $VERSION = '0.68';
+our $VERSION = '0.69';
 
 =head1 NAME
 
@@ -51,6 +51,7 @@ To get reference to array of all elements with same name ( selects, checkboxes,
 
 =back
 
+
 =over
 
 =item $cgi->param('filed_name');
@@ -88,7 +89,8 @@ our $MAX_URLENCODED_FIELDS = 1024;
 sub new { # init all structures
 	my($self) = @_;
 	
-	$self->start_timer;
+	# $self->start_timer;
+	$self->{timer} = EV::now;
 	
 	$self->{buffer} = HTTP::Server::EV::Buffer->new({ fd => $self->{fd} });
 	$self->{stdout_guard} = [];
@@ -155,7 +157,7 @@ Drops port listener callback processing. Don`t use it somewhere except HTTP::Ser
 
 =cut
 
-sub next { $_[0]->{received} ? goto(NEXT_REQ) : $_[0]-> drop};
+sub next { $_[0]->{received} ? goto(NEXT_REQ) : $_[0]->drop};
 
 =head2 $cgi->fd
 
@@ -180,7 +182,7 @@ sub fh {
 
 =head2 $cgi->buffer
 
-Returns handle tied to L<HTTP::Server::EV::Buffer> object. Writing to this handle buffered an non-blocking
+Returns handle tied to L<HTTP::Server::EV::Buffer> object. Writing to this handle buffered and non-blocking
 
 =cut
 
@@ -221,7 +223,7 @@ sub attach {
 
 =head2 $cgi->copy(*FH)
 
-Attaches socket to handle but don`t uses L<HTTP::Server::EV::BufTie> magick and buffered L<HTTP::Server::EV::Buffer> otput.
+Attaches socket to handle but doesn't use L<HTTP::Server::EV::BufTie> magick and buffered L<HTTP::Server::EV::Buffer> otput.
 
 =cut
 
@@ -262,32 +264,30 @@ Flush all buffered data and close received connection.
 =cut
 
 sub close { 
-	delete $_[0]->{buffer}; # From 0.21 HTTP::Server::EV::Buffer closes socket
+	delete $_[0]->{buffer}; # HTTP::Server::EV::Buffer closes socket
 	$_[0]->{stdout_guard} = []; # close all attached handles
-	#CORE::close $_[0]->{fh} ;
-	#HTTP::Server::EV::close_socket( $_[0]->{fd} );
 };
 
 
 =head2 $cgi->start_timer
 
-Initalize a page generation timer. Called automatically on every request
+Initialize a page generation timer. Called automatically on every request
 
 =head2 $cgi->flush_timer
 
-Returns string like '0.12345' with page generation time	
+Returns string like '0.12345678' with page generation time	
 
 =cut
 
 
 ### Page generation timer
-sub start_timer { shift->{timer}=[gettimeofday] }; # start/reset timer
-sub flush_timer { return tv_interval(shift->{timer}) }; # get generation time
+sub start_timer { $_[0]->{timer} = EV::now }; # start/reset timer
+sub flush_timer { return(EV::now - $_[0]->{timer}) }; # get generation time
 
 ### Get params as array refs. Ex: $cgi->post('checkboxes') - ['one','two']
-sub get { return $_[0]->{get_a}{$_[1]} ? $_[0]->{get_a}{$_[1]} : [] ;}
-sub post { return $_[0]->{post_a}{$_[1]} ? $_[0]->{post_a}{$_[1]} : [] ;}
-sub file { return $_[0]->{file_a}{$_[1]} ? $_[0]->{file_a}{$_[1]} : [] ;}
+sub get { $_[0]->{get_a}{$_[1]} || [] }
+sub post { $_[0]->{post_a}{$_[1]} || [] }
+sub file { $_[0]->{file_a}{$_[1]} || [] }
 sub param {
 	if(wantarray){
 		return( (@{$_[0]->{get_a}{$_[1]} || []}) ? @{$_[0]->{get_a}{$_[1]}}  : @{$_[0]->{post_a}{$_[1]} || []} );
@@ -380,7 +380,7 @@ sub urldecode {
 
 =head1 NOT RECEIVED REQUEST METHODS
 
-You can call these methods only after HTTP::Server::EV::PortListener on_multipart callback, when server receives POST data. You shouldn`t call them after request has received. 
+You should call these methods only after HTTP::Server::EV::PortListener on_multipart callback, when server receives POST data. You shouldn`t call them after request has been received. 
 
 =head2 $cgi->stop;
 
